@@ -4,18 +4,18 @@ from fastapi import APIRouter, Depends, Security, HTTPException, status
 from fastapi.security import OAuth2PasswordRequestForm
 from sqlalchemy.orm import Session
 
-from config import OAUTH_OAUTH_ROUTER, OAUTH_DEFAULT_TAGS, OAUTH_ACCESS_TOKEN_EXPIRE_MINUTES, OAUTH_LOGIN_SCOPES, OAUTH_ADMIN_USERS, OAUTH_SECRET_KEY, OAUTH_ALGORITHM, \
-    OAUTH_TOKEN_URI, OAUTH_SCOPES_URI
+from config import OAUTH_DEFAULT_TAGS, OAUTH_ACCESS_TOKEN_EXPIRE_MINUTES, OAUTH_LOGIN_SCOPES, OAUTH_ADMIN_USERS, OAUTH_SECRET_KEY, OAUTH_ALGORITHM, \
+    OAUTH_TOKEN_URI, OAUTH_SCOPES_URI, OAUTH_ME_URI
 from lsshu.internal.db import dbs
 from lsshu.internal.depends import model_screen_params, model_post_screen_params, auth_user
 from lsshu.internal.helpers import token_access_token, token_verify_password
-from lsshu.internal.schema import Schemas, ModelScreenParams
+from lsshu.internal.schema import Schemas, SchemasError, ModelScreenParams
 from lsshu.oauth.model import user_name
 from lsshu.oauth.permission.crud import CRUDOAuthPermission
 from lsshu.oauth.role.crud import CRUDOAuthRole
 from lsshu.oauth.user.crud import CRUDOAuthUser
 from lsshu.oauth.user.schema import SchemasOAuthScopes, SchemasLoginResponse, SchemasLogin, SchemasOAuthUserMeStatusResponse, SchemasPaginateItem, SchemasParams, \
-    SchemasOAuthUserResponse, SchemasOAuthUserStoreUpdate
+    SchemasOAuthUserResponse, SchemasOAuthUserStoreUpdate, SchemasOAuthUserMeUpdate
 
 tags = OAUTH_DEFAULT_TAGS + ['User']
 router = APIRouter(tags=tags)
@@ -94,6 +94,23 @@ async def get_scopes(auth: SchemasOAuthScopes = Security(auth_user)):
     return SchemasOAuthUserMeStatusResponse(data={"user": auth.user, "scopes": auth.scopes})
 
 
+@router.get(OAUTH_ME_URI)
+async def get_me(auth: SchemasOAuthScopes = Security(auth_user)):
+    """
+    获取登录授权的用户信息:
+    """
+    return Schemas(data=auth.user)
+
+
+@router.patch(OAUTH_ME_URI)
+async def patch_me(item: SchemasOAuthUserStoreUpdate, db: Session = Depends(dbs), auth: SchemasOAuthScopes = Security(auth_user)):
+    """
+    更新登录授权用户的信息:
+    """
+    bool_model = CRUDOAuthUser.update(db=db, pk=auth.user.id, item=item)
+    return Schemas(data=SchemasOAuthUserResponse(**bool_model.to_dict()))
+
+
 @router.get('/{}'.format(user_name), name="get {}".format(user_name))
 async def get_models(db: Session = Depends(dbs), params: ModelScreenParams = Depends(model_screen_params),
                      auth: SchemasOAuthScopes = Security(auth_user, scopes=user_scopes + ["%s.list" % user_name])):
@@ -148,7 +165,7 @@ async def get_model(pk: int, db: Session = Depends(dbs),
     """
     db_model = CRUDOAuthUser.first(db=db, where=(CRUDOAuthUser.params_pk, pk))
     if db_model is None:
-        raise HTTPException(status_code=status.HTTP_404_NOT_FOUND, detail="{} not found".format(user_name.capitalize()))
+        return SchemasError(message="Data Not Found")
     return Schemas(data=SchemasOAuthUserResponse(**db_model.to_dict()))
 
 
@@ -162,8 +179,7 @@ async def store_model(item: SchemasOAuthUserStoreUpdate, db: Session = Depends(d
     """
     db_model = CRUDOAuthUser.first(db=db, where=("username", item.username))
     if db_model is not None:
-        raise HTTPException(status_code=status.HTTP_400_BAD_REQUEST,
-                            detail="{} already registered".format(user_name.capitalize()))
+        return SchemasError(message="Data Already Registered")
     bool_model = CRUDOAuthUser.store(db=db, item=item)
     return Schemas(data=SchemasOAuthUserResponse(**bool_model.to_dict()))
 
@@ -180,7 +196,7 @@ async def update_put_model(pk: int, item: SchemasOAuthUserStoreUpdate, db: Sessi
     """
     db_model = CRUDOAuthUser.first(db=db, where=(CRUDOAuthUser.pk, pk))
     if db_model is None:
-        raise HTTPException(status_code=status.HTTP_404_NOT_FOUND, detail="{} not found".format(user_name.capitalize()))
+        return SchemasError(message="Data Not Found")
     bool_model = CRUDOAuthUser.update(db=db, pk=pk, item=item)
     return Schemas(data=SchemasOAuthUserResponse(**bool_model.to_dict()))
 
@@ -197,7 +213,7 @@ async def update_patch_model(pk: int, item: SchemasOAuthUserStoreUpdate, db: Ses
     """
     db_model = CRUDOAuthUser.first(db=db, where=(CRUDOAuthUser.pk, pk))
     if db_model is None:
-        raise HTTPException(status_code=status.HTTP_404_NOT_FOUND, detail="{} not found".format(user_name.capitalize()))
+        return SchemasError(message="Data Not Found")
     bool_model = CRUDOAuthUser.update(db=db, pk=pk, item=item, exclude_unset=True)
     return Schemas(data=SchemasOAuthUserResponse(**bool_model.to_dict()))
 
